Coverage report

|  |  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | --- | ---
File | class |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
src \ cmvk \ __init__.py | (no class) |  | 52% | 27 | 13 | 0 |  | 0% | 8 | 0 |  | 40%
src \ cmvk \ audit.py | AuditEntry |  | 0% | 3 | 3 | 0 |  | 100% | 0 | 0 |  | 0%
src \ cmvk \ audit.py | AuditTrail |  | 0% | 81 | 81 | 0 |  | 0% | 32 | 0 |  | 0%
src \ cmvk \ audit.py | (no class) |  | 76% | 62 | 15 | 0 |  | 0% | 6 | 0 |  | 69%
src \ cmvk \ benchmarks.py | TaskCategory |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ benchmarks.py | BenchmarkTask |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ benchmarks.py | ModelResponse |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ benchmarks.py | VerificationResult |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ benchmarks.py | BenchmarkResults |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ benchmarks.py | ConsensusMethod |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ benchmarks.py | CMVKBenchmark |  | 0% | 94 | 94 | 0 |  | 0% | 42 | 0 |  | 0%
src \ cmvk \ benchmarks.py | (no class) |  | 0% | 84 | 84 | 12 |  | 0% | 8 | 0 |  | 0%
src \ cmvk \ constitutional.py | Severity |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ constitutional.py | Principle |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ constitutional.py | PrincipleSet |  | 100% | 16 | 0 | 0 |  | 100% | 8 | 0 |  | 100%
src \ cmvk \ constitutional.py | Violation |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ constitutional.py | ValidationResult |  | 75% | 4 | 1 | 0 |  | 100% | 0 | 0 |  | 75%
src \ cmvk \ constitutional.py | PrincipleEvaluator |  | 0% | 2 | 2 | 0 |  | 100% | 0 | 0 |  | 0%
src \ cmvk \ constitutional.py | RuleBasedEvaluator |  | 100% | 8 | 0 | 0 |  | 100% | 4 | 0 |  | 100%
src \ cmvk \ constitutional.py | LLMEvaluator |  | 71% | 31 | 9 | 0 |  | 50% | 10 | 3 |  | 66%
src \ cmvk \ constitutional.py | ConstitutionalValidator |  | 80% | 54 | 11 | 0 |  | 50% | 22 | 3 |  | 71%
src \ cmvk \ constitutional.py | (no class) |  | 94% | 111 | 7 | 0 |  | 100% | 0 | 0 |  | 94%
src \ cmvk \ hf_utils.py | HuggingFaceHubError |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ hf_utils.py | (no class) |  | 0% | 79 | 79 | 2 |  | 0% | 10 | 0 |  | 0%
src \ cmvk \ metrics.py | DistanceMetric |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ metrics.py | MetricResult |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ metrics.py | (no class) |  | 24% | 131 | 100 | 0 |  | 0% | 32 | 0 |  | 19%
src \ cmvk \ profiles.py | ProfileName |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ profiles.py | ThresholdProfile |  | 0% | 9 | 9 | 0 |  | 0% | 6 | 0 |  | 0%
src \ cmvk \ profiles.py | (no class) |  | 73% | 48 | 13 | 0 |  | 0% | 6 | 0 |  | 65%
src \ cmvk \ types.py | (no class) |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ verification.py | DriftType |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src \ cmvk \ verification.py | VerificationScore |  | 0% | 2 | 2 | 0 |  | 100% | 0 | 0 |  | 0%
src \ cmvk \ verification.py | DriftExplanation |  | 0% | 1 | 1 | 0 |  | 100% | 0 | 0 |  | 0%
src \ cmvk \ verification.py | (no class) |  | 17% | 282 | 233 | 2 |  | 0% | 84 | 0 |  | 13%
Total |  |  | 33% | 1136 | 757 | 16 |  | 10% | 278 | 6 |  | 29%

No items found using the specified filter.